sumo.electronic\_structure package
===================================

Module contents
---------------

.. automodule:: sumo.electronic_structure
    :members:
    :undoc-members:
    :show-inheritance:


Submodules
----------

sumo.electronic\_structure.bandstructure module
------------------------------------------------

.. automodule:: sumo.electronic_structure.bandstructure
    :members:
    :undoc-members:
    :show-inheritance:

sumo.electronic\_structure.dos module
--------------------------------------

.. automodule:: sumo.electronic_structure.dos
    :members:
    :undoc-members:
    :show-inheritance:

sumo.electronic\_structure.effective\_mass module
--------------------------------------------------

.. automodule:: sumo.electronic_structure.effective_mass
    :members:
    :undoc-members:
    :show-inheritance:

sumo.electronic\_structure.optics module
-----------------------------------------

.. automodule:: sumo.electronic_structure.optics
    :members:
    :undoc-members:
    :show-inheritance:
